sff_lib
library
Classes
-
FileLog
-
Сlass for saving the result of file operations
-
Sff
-
A class for executing actions on sets
of directories (Storage) simultaneously.
-
SffYaml
-
Class of yaml file parsing.
-
Storage
-
Class for opening a directory with a specified permission.
Functions
-
compareFilesEquality(File file1, File file2)
→ Future<bool>
-
Comparing two files for content equality.
-
copyDirRec(Directory dirIn, Directory dirOut, {bool isCopyFile = true, bool filter(String)?})
→ Stream<FileLog>
-
Recursively copying a file with its contents.
-
findDuplicates(List<Directory> dirs, {File? file, bool filter(String)?})
→ Stream<FileLog>
-
Stream the channel that transmits (FileLog),
where the first is the original file and second is a duplicate.
-
generateHashFile(File file, [Hash hashMethod = sha1])
→ Future<Digest>
-
Method that generates a hash code from the contents of a file.
-
moveDir(Directory dir1, Directory dir2)
→ Stream<FileLog>
-
Recursively copying a file with its contents, and deletes the copied content.
-
recListFile(Directory dir)
→ Stream<File>
-
Recursively browses the contents of a directory and returns type File.
-
syncDir(Directory dir1, Directory dir2, {bool isCopyFile = true, bool filter(String)?})
→ Stream<FileLog>
-
Recursively copies the contents from the first directory
to another, and then in the same way but on the reverse.